@@ -1255,12 +1255,14 @@ class Handler(object):
     def write_to_csv(list_of_dicts,
                      outfile=None,
                      append=False,
+                     null_value=None,
                      delimiter=','):
 
         """
         Method to write to a csv file
         :param list_of_dicts: list of dictionaries to be written
         :param outfile: output file name
+        :param null_value: Value to substitute if column is not available in a dict
         :param delimiter: Delimiter examples : ,  ; |
         :param append: If the output should be appended to an already exising file
         """
@@ -1277,28 +1279,36 @@ class Handler(object):
                     colname_string = f.readline().strip()
                 if len(colname_string) > 0:
                     colnames = [elem.strip() for elem in colname_string.split(delimiter)]
-                    lines = list(delimiter.join(list(str(elem_dict[colname]) for colname in colnames))
+                    lines = list(delimiter.join(list(str(elem_dict[colname]) if colname in elem_dict
+                                                     else str(null_value)
+                                                     for colname in colnames))
                                  for elem_dict in list_of_dicts)
                 else:
                     colnames = list(list_of_dicts[0].keys())
-                    lines = [delimiter.join(colnames)] + \
-                        list(delimiter.join(list(str(elem_dict[colname]) for colname in colnames))
+                    lines = [delimiter.join(list(str(colname) for colname in colnames))] + \
+                        list(delimiter.join(list(str(elem_dict[colname]) if colname in elem_dict
+                                                 else str(null_value)
+                                                 for colname in colnames))
                              for elem_dict in list_of_dicts)
                 with open(outfile, 'a') as f:
                     for line in lines:
                         f.write(line + '\n')
             else:
                 colnames = list(list_of_dicts[0].keys())
-                lines = [delimiter.join(colnames)] + \
-                    list(delimiter.join(list(str(elem_dict[colname]) for colname in colnames))
+                lines = [delimiter.join(list(str(colname) for colname in colnames))] + \
+                    list(delimiter.join(list(str(elem_dict[colname]) if colname in elem_dict
+                                             else str(null_value)
+                                             for colname in colnames))
                          for elem_dict in list_of_dicts)
                 with open(outfile, 'w') as f:
                     for line in lines:
                         f.write(line + '\n')
         else:
             colnames = list(list_of_dicts[0].keys())
-            lines = [delimiter.join(colnames)] + \
-                list(delimiter.join(list(str(elem_dict[colname]) for colname in colnames))
+            lines = [delimiter.join(list(str(colname) for colname in colnames))] + \
+                list(delimiter.join(list(str(elem_dict[colname]) if colname in elem_dict
+                                         else str(null_value)
+                                         for colname in colnames))
                      for elem_dict in list_of_dicts)
             with open(outfile, 'w') as f:
                 for line in lines:
