@@ -965,13 +965,13 @@ class Raster(object):
             if y + tile_ysize < ymax:
                 rows = tile_ysize
             else:
-                rows = ymax - y
+                rows = ymax - y + 1
 
             for x in range(xmin, xmax, tile_xsize):
                 if x + tile_xsize < xmax:
                     cols = tile_xsize
                 else:
-                    cols = xmax - x
+                    cols = xmax - x + 1
 
                 tie_pt = self.get_coords([(x, y)],
                                          (self.transform[1], self.transform[5]),
